import java.awt.*;
import java.awt.event.*;
import java.applet.*;
import java.util.*;
import java.io.*;

public class PumpApplet extends Applet {
    PumpSimulator ps;
    TextArea o;
    PumpVariable ref_chain; 

    public void init() {
	setFont(new Font("Dialog",Font.PLAIN, 12));
	setBackground(Color.white);
	setForeground(Color.black);
        ps = new PumpSimulator(PumpSimulator.t,PumpSimulator.s,1.802,0.01,1, 10);
	ref_chain = new PumpVariable(10);
	o = new TextArea("Choose parameters and press [Run]...",10,80);
	o.setSize(500,200);
	add(o);
    }

    public void reinit(String iterations, String sweeps, String catalysts) {
	try {
	    if(iterations != null)
		ps.number_of_iterations = Integer.parseInt(iterations);
	} catch(NumberFormatException e) { ps.number_of_iterations = 50; showStatus("error: using 50 iterations");};

	try {
	    if(sweeps != null)
		ps.number_of_sweeps = Integer.parseInt(sweeps);
	} catch(NumberFormatException e) {ps.number_of_sweeps = 35; showStatus("error: using 35 sweeps");};

	try {
	    if(catalysts != null)
		ps.number_of_catalysts_per_sweep = Integer.parseInt(catalysts);
	} catch(NumberFormatException e) {ps.number_of_catalysts_per_sweep = 10; showStatus("error: setting catalysts=10");};

	do_simulation_run();
    }

    public void do_simulation_run() {
	

	showStatus("setting up the simulation");
	StringBuffer sbuf = new StringBuffer(4096); 

	sbuf.append("Number of iterations: " + ps.number_of_iterations
			       + "\nUsing " + ps.number_of_sweeps 
			       + " sweeps/iteration and " +
			       ps.number_of_catalysts_per_sweep +
			       " catalysts/sweep.\n\n");
	sbuf.append(" X_0 = ["+ref_chain+"]\n");

	boolean first = true;
	int j = 1;
	PumpVariable old_chain = new PumpVariable(10);
	for(int i = 0; i < ps.number_of_iterations; i++) {
	    showStatus("now performing iteration " + i);
	    // save the state just prior to testing for coalescence
	    old_chain.beta = ref_chain.beta;
	    System.arraycopy(ref_chain.lambda,0,old_chain.lambda,0,10);
	    // do the coalescence thing
	    ref_chain = ps.bigSweep(ref_chain, ps.number_of_sweeps, 
				    ps.number_of_catalysts_per_sweep);
	    sbuf.append("" + (i+1) + ": K_B \\subset [0, "+ps.L+"]");
	    if( ps.fully_coupled )
		sbuf.append(" - fully coupled");
	    else
		sbuf.append(" - not coupled");
	    if( ps.coalesced ) {
		sbuf.append(" + coalesced\n");
		sbuf.append(" T_"+j+" = "+i+"\n");
	    } else
		sbuf.append(" - not coalesced\n");
	    
	    sbuf.append(" X_"+(i+1)+" = ["+ref_chain+"]\n");
	    if( ps.coalesced ) j++;
	    if( first ) {
		first = false;
	    }
	}
	showStatus("done!");
	sbuf.append("Produced an IID sample of size " + (j-2));

	o.setText(sbuf.toString());
	o.repaint();
    }
}














